All pastes #262114 Raw Edit

Stuff

public text v1 · immutable
#262114 ·published 2006-11-30 04:41 UTC
rendered paste body
nvidia-installer log file '/var/log/nvidia-installer.log'
creation time: Wed Nov 29 21:30:01 2006

option status:
  license pre-accepted    : false
  update                  : false
  force update            : false
  expert                  : false
  uninstall               : false
  driver info             : false
  precompiled interfaces  : true
  no ncurses color        : false
  query latest version    : false
  OpenGL header files     : true
  no questions            : false
  silent                  : false
  no recursion            : false
  no backup               : false
  kernel module only      : false
  sanity                  : false
  add this kernel         : false
  no runlevel check       : false
  no network              : false
  no ABI note             : false
  no RPMs                 : false
  no kernel module        : false
  force SELinux           : default
  no X server check       : false
  force tls               : (not specified)
  X install prefix        : (not specified)
  X library install path  : (not specified)
  X module install path   : (not specified)
  OpenGL install prefix   : (not specified)
  OpenGL install libdir   : (not specified)
  utility install prefix  : (not specified)
  utility install libdir  : (not specified)
  doc install prefix      : (not specified)
  kernel name             : (not specified)
  kernel include path     : (not specified)
  kernel source path      : (not specified)
  kernel output path      : (not specified)
  kernel install path     : (not specified)
  proc mount point        : /proc
  ui                      : (not specified)
  tmpdir                  : /root/tmp
  ftp mirror              : ftp://download.nvidia.com
  RPM file list           : (not specified)

Using: nvidia-installer ncurses user interface
-> License accepted.
-> There appears to already be a driver installed on your system (version: 1.0-
   9629).  As part of installing this driver (version: 1.0-9629), the existing 
   driver will be uninstalled.  Are you sure you want to continue? ('no' will a
   bort installation) (Answer: Yes)
-> No precompiled kernel interface was found to match your kernel; would you li
   ke the installer to attempt to download a kernel interface for your kernel f
   rom the NVIDIA ftp site (ftp://download.nvidia.com)? (Answer: Yes)
-> No matching precompiled kernel interface was found on the NVIDIA ftp site;
   this means that the installer will need to compile a kernel interface for
   your kernel.
-> Performing CC sanity check with CC="cc".
-> Performing CC version check with CC="cc".
-> Kernel source path: '/lib/modules/2.6.17-5mdv/source'
-> Kernel output path: '/lib/modules/2.6.17-5mdv/build'
-> Performing rivafb check.
-> Performing nvidiafb check.
-> Cleaning kernel module build directory.
   executing: 'cd ./usr/src/nv; make clean'...
   rm -f -f nv.o nv-vm.o os-agp.o os-interface.o os-registry.o nv-i2c.o nv.o nv
   -vm.o os-agp.o os-interface.o os-registry.o nv-i2c.o nvidia.mod.o
   rm -f -f build-in.o nv-linux.o *.d .*.{cmd,flags}
   rm -f -f nvidia.{o,ko,mod.{o,c}} nv_compiler.h *~
   rm -f -f stprof stprof.o symtab.h Modules.symvers
   rm -f -rf .tmp_versions
-> Building kernel module:
   executing: 'cd ./usr/src/nv; make module SYSSRC=/lib/modules/2.6.17-5mdv/sou
   rce SYSOUT=/lib/modules/2.6.17-5mdv/build'...
   
   NVIDIA: calling KBUILD...
   make CC=cc KBUILD_OUTPUT=/lib/modules/2.6.17-5mdv/build KBUILD_VERBOSE=1 -C 
   /lib/modules/2.6.17-5mdv/source SUBDIRS=/root/tmp/selfgz5388/NVIDIA-Linux-x8
   6-1.0-9629-pkg1/usr/src/nv modules
   make -C /lib/modules/2.6.17-5mdv/build \
   	KBUILD_SRC=/usr/src/linux-2.6.17-5mdv \
   	KBUILD_EXTMOD="/root/tmp/selfgz5388/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/
   nv" -f /usr/src/linux-2.6.17-5mdv/Makefile modules
   mkdir -p /root/tmp/selfgz5388/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/.tmp
   _versions
   rm -f /root/tmp/selfgz5388/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/.tmp_ve
   rsions/*
   
     WARNING: Symbol version dump /usr/src/linux-2.6.17-5mdv/Module.symvers
              is missing; modules will have no dependencies and modversions.
   
   make -f /usr/src/linux-2.6.17-5mdv/scripts/Makefile.build obj=/root/tmp/self
   gz5388/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv
   echo \#define NV_COMPILER \"`cc -v 2>&1 | tail -n 1`\" > /root/tmp/selfgz538
   8/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/nv_compiler.h
     cc -Wp,-MD,/root/tmp/selfgz5388/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/
   .nv.o.d  -nostdinc -isystem /usr/lib/gcc/i586-mandriva-linux-gnu/4.1.1/inclu
   de -D__KERNEL__ -Iinclude -Iinclude2 -I/usr/src/linux-2.6.17-5mdv/include -i
   nclude include/linux/autoconf.h   -I/root/tmp/selfgz5388/NVIDIA-Linux-x86-1.
   0-9629-pkg1/usr/src/nv -Wall -Wundef -Wstrict-prototypes -Wno-trigraphs -fno
   -strict-aliasing -fno-common -O2 -fno-omit-frame-pointer -fno-optimize-sibli
   ng-calls -pipe -msoft-float -mpreferred-stack-boundary=2 -march=i686 -ffrees
   tanding -I/usr/src/linux-2.6.17-5mdv/include/asm-i386/mach-default -Iinclude
   /asm-i386/mach-default -Wdeclaration-after-statement -Wno-pointer-sign  -I/r
   oot/tmp/selfgz5388/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv -Wall -Wimplici
   t -Wreturn-type -Wswitch -Wformat -Wchar-subscripts -Wparentheses -Wpointer-
   arith -Wno-multichar -Werror -O -fno-common -msoft-float -MD -Wsign-compare 
   -Wno-cast-qual -Wno-error -D_LOOSE_KERNEL_NAMES -D__KERNEL__ -DMODULE -DNVRM
   -DNV_MAJOR_VERSION=1 -DNV_MINOR_VERSION=0 -DNV_PATCHLEVE
   L=9629 -UDEBUG -U_DEBUG -DNDEBUG -DNV_SIGNAL_STRUCT_RLIM -DNV_MULTIPLE_BRIDG
   E_AGPGART_PRESENT -DNV_PCI_GET_CLASS_PRESENT -DNV_SYSCTL_MAX_MAP_COUNT_PRESE
   NT -DNV_PM_MESSAGE_T_PRESENT -DNV_IRQ_HANDLER_WITH_PTREGS_PRESENT -DNV_PCI_C
   HOOSE_STATE_PRESENT -DNV_VM_INSERT_PAGE_PRESENT -DNV_OLD_MM_KGDB_BREAKPOINT_
   PRESENT -DNV_REMAP_PFN_RANGE_PRESENT -DNV_CHANGE_PAGE_ATTR_PRESENT -DNV_VMAP
   _4_PRESENT -DMODULE -D"KBUILD_STR(s)=#s" -D"KBUILD_BASENAME=KBUILD_STR(nv)" 
   -D"KBUILD_MODNAME=KBUILD_STR(nvidia)" -c -o /root/tmp/selfgz5388/NVIDIA-Linu
   x-x86-1.0-9629-pkg1/usr/src/nv/nv.o /root/tmp/selfgz5388/NVIDIA-Linux-x86-1.
   0-9629-pkg1/usr/src/nv/nv.c
   In file included from include/linux/dmapool.h:14,
                    from include/linux/pci.h:559,
                    from /root/tmp/selfgz5388/NVIDIA-Linux-x86-1.0-9629-pkg1/us
   r/src/nv/nv-linux.h:77,
                    from /root/tmp/selfgz5388/NVIDIA-Linux-x86-1.0-9629-pkg1/us
   r/src/nv/nv.c:14:
   include/asm/io.h: In function ‘check_signature’:
   include/asm/io.h:246: warning: wrong type argument to increment
     cc -Wp,-MD,/root/tmp/selfgz5388/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/
   .nv-vm.o.d  -nostdinc -isystem /usr/lib/gcc/i586-mandriva-linux-gnu/4.1.1/in
   clude -D__KERNEL__ -Iinclude -Iinclude2 -I/usr/src/linux-2.6.17-5mdv/include
   -include include/linux/autoconf.h   -I/root/tmp/selfgz5388/NVIDIA-Linux-x86-
   1.0-9629-pkg1/usr/src/nv -Wall -Wundef -Wstrict-prototypes -Wno-trigraphs -f
   no-strict-aliasing -fno-common -O2 -fno-omit-frame-pointer -fno-optimize-sib
   ling-calls -pipe -msoft-float -mpreferred-stack-boundary=2 -march=i686 -ffre
   estanding -I/usr/src/linux-2.6.17-5mdv/include/asm-i386/mach-default -Iinclu
   de/asm-i386/mach-default -Wdeclaration-after-statement -Wno-pointer-sign  -I
   /root/tmp/selfgz5388/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv -Wall -Wimpli
   cit -Wreturn-type -Wswitch -Wformat -Wchar-subscripts -Wparentheses -Wpointe
   r-arith -Wno-multichar -Werror -O -fno-common -msoft-float -MD -Wsign-compar
   e -Wno-cast-qual -Wno-error -D_LOOSE_KERNEL_NAMES -D__KERNEL__ -DMODULE -DNV
   RM -DNV_MAJOR_
   VERSION=1 -DNV_MINOR_VERSION=0 -DNV_PATCHLEVEL=9629 -UDEBUG -U_DEBUG -DNDEBU
   G -DNV_SIGNAL_STRUCT_RLIM -DNV_MULTIPLE_BRIDGE_AGPGART_PRESENT -DNV_PCI_GET_
   CLASS_PRESENT -DNV_SYSCTL_MAX_MAP_COUNT_PRESENT -DNV_PM_MESSAGE_T_PRESENT -D
   NV_IRQ_HANDLER_WITH_PTREGS_PRESENT -DNV_PCI_CHOOSE_STATE_PRESENT -DNV_VM_INS
   ERT_PAGE_PRESENT -DNV_OLD_MM_KGDB_BREAKPOINT_PRESENT -DNV_REMAP_PFN_RANGE_PR
   ESENT -DNV_CHANGE_PAGE_ATTR_PRESENT -DNV_VMAP_4_PRESENT -DMODULE -D"KBUILD_S
   TR(s)=#s" -D"KBUILD_BASENAME=KBUILD_STR(nv_vm)"  -D"KBUILD_MODNAME=KBUILD_ST
   R(nvidia)" -c -o /root/tmp/selfgz5388/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src
   /nv/nv-vm.o /root/tmp/selfgz5388/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/n
   v-vm.c
   In file included from include/linux/dmapool.h:14,
                    from include/linux/pci.h:559,
                    from /root/tmp/selfgz5388/NVIDIA-Linux-x86-1.0-9629-pkg1/us
   r/src/nv/nv-linux.h:77,
                    from /root/tmp/selfgz5388/NVIDIA-Linux-x86-1.0-9629-pkg1/us
   r/src/nv/nv-vm.c:14:
   include/asm/io.h: In function ‘check_signature’:
   include/asm/io.h:246: warning: wrong type argument to increment
     cc -Wp,-MD,/root/tmp/selfgz5388/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/
   .os-agp.o.d  -nostdinc -isystem /usr/lib/gcc/i586-mandriva-linux-gnu/4.1.1/i
   nclude -D__KERNEL__ -Iinclude -Iinclude2 -I/usr/src/linux-2.6.17-5mdv/includ
   e -include include/linux/autoconf.h   -I/root/tmp/selfgz5388/NVIDIA-Linux-x8
   6-1.0-9629-pkg1/usr/src/nv -Wall -Wundef -Wstrict-prototypes -Wno-trigraphs 
   -fno-strict-aliasing -fno-common -O2 -fno-omit-frame-pointer -fno-optimize-s
   ibling-calls -pipe -msoft-float -mpreferred-stack-boundary=2 -march=i686 -ff
   reestanding -I/usr/src/linux-2.6.17-5mdv/include/asm-i386/mach-default -Iinc
   lude/asm-i386/mach-default -Wdeclaration-after-statement -Wno-pointer-sign  
   -I/root/tmp/selfgz5388/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv -Wall -Wimp
   licit -Wreturn-type -Wswitch -Wformat -Wchar-subscripts -Wparentheses -Wpoin
   ter-arith -Wno-multichar -Werror -O -fno-common -msoft-float -MD -Wsign-comp
   are -Wno-cast-qual -Wno-error -D_L
   OOSE_KERNEL_NAMES -D__KERNEL__ -DMODULE -DNVRM -DNV_MAJOR_VERSION=1 -DNV_MIN
   OR_VERSION=0 -DNV_PATCHLEVEL=9629 -UDEBUG -U_DEBUG -DNDEBUG -DNV_SIGNAL_STRU
   CT_RLIM -DNV_MULTIPLE_BRIDGE_AGPGART_PRESENT -DNV_PCI_GET_CLASS_PRESENT -DNV
   _SYSCTL_MAX_MAP_COUNT_PRESENT -DNV_PM_MESSAGE_T_PRESENT -DNV_IRQ_HANDLER_WIT
   H_PTREGS_PRESENT -DNV_PCI_CHOOSE_STATE_PRESENT -DNV_VM_INSERT_PAGE_PRESENT -
   DNV_OLD_MM_KGDB_BREAKPOINT_PRESENT -DNV_REMAP_PFN_RANGE_PRESENT -DNV_CHANGE_
   PAGE_ATTR_PRESENT -DNV_VMAP_4_PRESENT -DMODULE -D"KBUILD_STR(s)=#s" -D"KBUIL
   D_BASENAME=KBUILD_STR(os_agp)"  -D"KBUILD_MODNAME=KBUILD_STR(nvidia)" -c -o 
   /root/tmp/selfgz5388/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/os-agp.o /roo
   t/tmp/selfgz5388/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/os-agp.c
   In file included from include/linux/dmapool.h:14,
                    from include/linux/pci.h:559,
                    from /root/tmp/selfgz5388/NVIDIA-Linux-x86-1.0-9629-pkg1/us
   r/src/nv/nv-linux.h:77,
                    from /root/tmp/selfgz5388/NVIDIA-Linux-x86-1.0-9629-pkg1/us
   r/src/nv/os-agp.c:24:
   include/asm/io.h: In function ‘check_signature’:
   include/asm/io.h:246: warning: wrong type argument to increment
     cc -Wp,-MD,/root/tmp/selfgz5388/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/
   .os-interface.o.d  -nostdinc -isystem /usr/lib/gcc/i586-mandriva-linux-gnu/4
   .1.1/include -D__KERNEL__ -Iinclude -Iinclude2 -I/usr/src/linux-2.6.17-5mdv/
   include -include include/linux/autoconf.h   -I/root/tmp/selfgz5388/NVIDIA-Li
   nux-x86-1.0-9629-pkg1/usr/src/nv -Wall -Wundef -Wstrict-prototypes -Wno-trig
   raphs -fno-strict-aliasing -fno-common -O2 -fno-omit-frame-pointer -fno-opti
   mize-sibling-calls -pipe -msoft-float -mpreferred-stack-boundary=2 -march=i6
   86 -ffreestanding -I/usr/src/linux-2.6.17-5mdv/include/asm-i386/mach-default
   -Iinclude/asm-i386/mach-default -Wdeclaration-after-statement -Wno-pointer-s
   ign  -I/root/tmp/selfgz5388/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv -Wall 
   -Wimplicit -Wreturn-type -Wswitch -Wformat -Wchar-subscripts -Wparentheses -
   Wpointer-arith -Wno-multichar -Werror -O -fno-c
   ommon -msoft-float -MD -Wsign-compare -Wno-cast-qual -Wno-error -D_LOOSE_KER
   NEL_NAMES -D__KERNEL__ -DMODULE -DNVRM -DNV_MAJOR_VERSION=1 -DNV_MINOR_VERSI
   ON=0 -DNV_PATCHLEVEL=9629 -UDEBUG -U_DEBUG -DNDEBUG -DNV_SIGNAL_STRUCT_RLIM 
   -DNV_MULTIPLE_BRIDGE_AGPGART_PRESENT -DNV_PCI_GET_CLASS_PRESENT -DNV_SYSCTL_
   MAX_MAP_COUNT_PRESENT -DNV_PM_MESSAGE_T_PRESENT -DNV_IRQ_HANDLER_WITH_PTREGS
   _PRESENT -DNV_PCI_CHOOSE_STATE_PRESENT -DNV_VM_INSERT_PAGE_PRESENT -DNV_OLD_
   MM_KGDB_BREAKPOINT_PRESENT -DNV_REMAP_PFN_RANGE_PRESENT -DNV_CHANGE_PAGE_ATT
   R_PRESENT -DNV_VMAP_4_PRESENT -DMODULE -D"KBUILD_STR(s)=#s" -D"KBUILD_BASENA
   ME=KBUILD_STR(os_interface)"  -D"KBUILD_MODNAME=KBUILD_STR(nvidia)" -c -o /r
   oot/tmp/selfgz5388/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/os-interface.o 
   /root/tmp/selfgz5388/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/os-interface.
   c
   In file included from include/linux/dmapool.h:14,
                    from include/linux/pci.h:559,
                    from /root/tmp/selfgz5388/NVIDIA-Linux-x86-1.0-9629-pkg1/us
   r/src/nv/nv-linux.h:77,
                    from /root/tmp/selfgz5388/NVIDIA-Linux-x86-1.0-9629-pkg1/us
   r/src/nv/os-interface.c:26:
   include/asm/io.h: In function ‘check_signature’:
   include/asm/io.h:246: warning: wrong type argument to increment
     cc -Wp,-MD,/root/tmp/selfgz5388/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/
   .os-registry.o.d  -nostdinc -isystem /usr/lib/gcc/i586-mandriva-linux-gnu/4.
   1.1/include -D__KERNEL__ -Iinclude -Iinclude2 -I/usr/src/linux-2.6.17-5mdv/i
   nclude -include include/linux/autoconf.h   -I/root/tmp/selfgz5388/NVIDIA-Lin
   ux-x86-1.0-9629-pkg1/usr/src/nv -Wall -Wundef -Wstrict-prototypes -Wno-trigr
   aphs -fno-strict-aliasing -fno-common -O2 -fno-omit-frame-pointer -fno-optim
   ize-sibling-calls -pipe -msoft-float -mpreferred-stack-boundary=2 -march=i68
   6 -ffreestanding -I/usr/src/linux-2.6.17-5mdv/include/asm-i386/mach-default 
   -Iinclude/asm-i386/mach-default -Wdeclaration-after-statement -Wno-pointer-s
   ign  -I/root/tmp/selfgz5388/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv -Wall 
   -Wimplicit -Wreturn-type -Wswitc
   h -Wformat -Wchar-subscripts -Wparentheses -Wpointer-arith -Wno-multichar -W
   error -O -fno-common -msoft-float -MD -Wsign-compare -Wno-cast-qual -Wno-err
   or -D_LOOSE_KERNEL_NAMES -D__KERNEL__ -DMODULE -DNVRM -DNV_MAJOR_VERSION=1 -
   DNV_MINOR_VERSION=0 -DNV_PATCHLEVEL=9629 -UDEBUG -U_DEBUG -DNDEBUG -DNV_SIGN
   AL_STRUCT_RLIM -DNV_MULTIPLE_BRIDGE_AGPGART_PRESENT -DNV_PCI_GET_CLASS_PRESE
   NT -DNV_SYSCTL_MAX_MAP_COUNT_PRESENT -DNV_PM_MESSAGE_T_PRESENT -DNV_IRQ_HAND
   LER_WITH_PTREGS_PRESENT -DNV_PCI_CHOOSE_STATE_PRESENT -DNV_VM_INSERT_PAGE_PR
   ESENT -DNV_OLD_MM_KGDB_BREAKPOINT_PRESENT -DNV_REMAP_PFN_RANGE_PRESENT -DNV_
   CHANGE_PAGE_ATTR_PRESENT -DNV_VMAP_4_PRESENT -DMODULE -D"KBUILD_STR(s)=#s" -
   D"KBUILD_BASENAME=KBUILD_STR(os_registry)"  -D"KBUILD_MODNAME=KBUILD_STR(nvi
   dia)" -c -o /root/tmp/selfgz5388/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/o
   s-registry.o /root/tmp/selfgz5388/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/
   os-registry.c
   In file included from include/linux/dmapool.h:14,
                    from include/linux/pci.h:559,
                    from /root/tmp/selfgz5388/NVIDIA-Linux-x86-1.0-9629-pkg1/us
   r/src/nv/nv-linux.h:77,
                    from /root/tmp/selfgz5388/NVIDIA-Linux-x86-1.0-9629-pkg1/us
   r/src/nv/os-registry.c:14:
   include/asm/io.h: In function ‘check_signature’:
   include/asm/io.h:246: warning: wrong type argument to increment
     cc -Wp,-MD,/root/tmp/selfgz5388/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/
   .nv-i2c.o.d  -nostdinc -isystem /usr/lib/gcc/i586-mandriva-linux-gnu/4.1.1/i
   nclude -D__KERNEL__ -Iinclude -Iinclude2 -I/usr/src/linux-2.6.17-5mdv/includ
   e -include include/linux/autoconf.h   -I/root/tmp/selfgz5388/NVIDIA-Linux-x8
   6-1.0-9629-pkg1/usr/src/nv -Wall -Wundef -Wstrict-prototypes -Wno-trigraphs 
   -fno-strict-aliasing -fno-common -O2 -fno-omit-frame-pointer -fno-optimize-s
   ibling-calls -pipe -msoft-float -mpreferred-stack-boundary=2 -march=i686 -ff
   reestanding -I/usr/src/linux-2.6.17-5mdv/include/asm-i386/mach-default -Iinc
   lude/asm-i386/mach-default -Wdeclaration-after-statement -Wno-pointer-sign  
   -I/root/tmp/selfgz538
   8/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv -Wall -Wimplicit -Wreturn-type -
   Wswitch -Wformat -Wchar-subscripts -Wparentheses -Wpointer-arith -Wno-multic
   har -Werror -O -fno-common -msoft-float -MD -Wsign-compare -Wno-cast-qual -W
   no-error -D_LOOSE_KERNEL_NAMES -D__KERNEL__ -DMODULE -DNVRM -DNV_MAJOR_VERSI
   ON=1 -DNV_MINOR_VERSION=0 -DNV_PATCHLEVEL=9629 -UDEBUG -U_DEBUG -DNDEBUG -DN
   V_SIGNAL_STRUCT_RLIM -DNV_MULTIPLE_BRIDGE_AGPGART_PRESENT -DNV_PCI_GET_CLASS
   _PRESENT -DNV_SYSCTL_MAX_MAP_COUNT_PRESENT -DNV_PM_MESSAGE_T_PRESENT -DNV_IR
   Q_HANDLER_WITH_PTREGS_PRESENT -DNV_PCI_CHOOSE_STATE_PRESENT -DNV_VM_INSERT_P
   AGE_PRESENT -DNV_OLD_MM_KGDB_BREAKPOINT_PRESENT -DNV_REMAP_PFN_RANGE_PRESENT
   -DNV_CHANGE_PAGE_ATTR_PRESENT -DNV_VMAP_4_PRESENT -DMODULE -D"KBUILD_STR(s)=
   #s" -D"KBUILD_BASENAME=KBUILD_STR(nv_i2c)"  -D"KBUILD_MODNAME=KBUILD_STR(nvi
   dia)" -c -o /root/tmp/selfgz5388/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/n
   v-i2c.o /root/tmp/selfgz5388/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/nv-i2
   c.c
   In file included from include/linux/dmapool.h:14,
                    from include/linux/pci.h:559,
                    from /root/tmp/selfgz5388/NVIDIA-Linux-x86-1.0-9629-pkg1/us
   r/src/nv/nv-linux.h:77,
                    from /root/tmp/selfgz5388/NVIDIA-Linux-x86-1.0-9629-pkg1/us
   r/src/nv/nv-i2c.c:8:
   include/asm/io.h: In function ‘check_signature’:
   include/asm/io.h:246: warning: wrong type argument to increment
     ld -m elf_i386 -m elf_i386  -r -o /root/tmp/selfgz5388/NVIDIA-Linux-x86-1.
   0-9629-pkg1/usr/src/nv/nvidia.o /root/tmp/selfgz5388/NVIDIA-Linux-x86-1.0-96
   29-pkg1/usr/src/nv/nv-kernel.o /root/tmp/selfgz5388/NVIDIA-Linux-x86-1.0-962
   9-pkg1/usr/src/nv/nv.o /root/tmp/selfgz5388/NVIDIA-Linux-x86-1.0-9629-pkg1/u
   sr/src/nv/nv-vm.o /root/tmp/selfgz5388/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/sr
   c/nv/os-agp.o /root/tmp/selfgz5388/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv
   /os-interface.o /root/tmp/selfgz5388/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/
   nv/os-registry.o /root/tmp/selfgz5388/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src
   /nv/nv-i2c.o
     Building modules, stage 2.
   make -rR -f /usr/src/linux-2.6.17-5mdv/scripts/Makefile.modpost
     scripts/mod/modpost   -i /usr/src/linux-2.6.17-5mdv/Module.symvers -I /roo
   t/tmp/selfgz5388/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/Modules.symvers -
   o /root/tmp/selfgz5388/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/Modules.sym
   vers /root/tmp/selfgz5388/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/nvidia.o
     cc -Wp,-MD,/root/tmp/selfgz5388/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/
   .nvidia.mod.o.d  -nostdinc -isystem /usr/lib/gcc/i586-mandriva-linux-gnu/4.1
   .1/include -D__KERNEL__ -Iinclude -Iinclude2 -I/usr/src/linux-2.6.17-5mdv/in
   clude -include include/linux/autoconf.h  -I/usr/src/linux-2.6.17-5mdv/ -I -W
   all -Wundef -Wstrict-prototypes -Wno-trigraphs -fno-strict-aliasing -fno-com
   mon -O2 -fno-omit-frame-pointer -fno-optimize-sibling-calls -pipe -msoft-flo
   at -mpreferred-stack-boundary=2 -march=i686 -ffreestanding -I/usr/src/linux-
   2.6.17-5mdv/include/asm-i386/mach-default -Iinclude/asm-i386/mach-default -W
   declaration-after-statement -Wno-pointer-
   sign  -D"KBUILD_STR(s)=#s" -D"KBUILD_BASENAME=KBUILD_STR(nvidia)"  -D"KBUILD
   _MODNAME=KBUILD_STR(nvidia)" -DMODULE -c -o /root/tmp/selfgz5388/NVIDIA-Linu
   x-x86-1.0-9629-pkg1/usr/src/nv/nvidia.mod.o /root/tmp/selfgz5388/NVIDIA-Linu
   x-x86-1.0-9629-pkg1/usr/src/nv/nvidia.mod.c
     ld -m elf_i386 -m elf_i386 -r -o /root/tmp/selfgz5388/NVIDIA-Linux-x86-1.0
   -9629-pkg1/usr/src/nv/nvidia.ko /root/tmp/selfgz5388/NVIDIA-Linux-x86-1.0-96
   29-pkg1/usr/src/nv/nvidia.o /root/tmp/selfgz5388/NVIDIA-Linux-x86-1.0-9629-p
   kg1/usr/src/nv/nvidia.mod.o
   NVIDIA: left KBUILD.
-> done.
-> Kernel module compilation complete.
-> Kernel messages:
   atkbd.c: Use 'setkeycodes e059 <keycode>' to make it known.
   atkbd.c: Unknown key pressed (translated set 2, code 0xd9 on
   isa0060/serio0).
   atkbd.c: Use 'setkeycodes e059 <keycode>' to make it known.
   atkbd.c: Unknown key pressed (translated set 2, code 0xd9 on
   isa0060/serio0).
   atkbd.c: Use 'setkeycodes e059 <keycode>' to make it known.
   atkbd.c: Unknown key pressed (translated set 2, code 0xd9 on
   isa0060/serio0).
   atkbd.c: Use 'setkeycodes e059 <keycode>' to make it known.
   bootsplash 3.1.6-2004/03/31: looking for picture...<6>...found (800x600,
   12546 bytes, v3).
   bootsplash: status on console 0 changed to on
   bootsplash 3.1.6-2004/03/31: looking for picture...<6>...found (800x600,
   12546 bytes, v3).
   bootsplash: status on console 1 changed to on
   bootsplash 3.1.6-2004/03/31: looking for picture...<6>...found (800x600,
   12546 bytes, v3).
   bootsplash: status on console 2 changed to on
   bootsplash 3.1.6-2004/03/31: looking for picture...<6>...found (800x600,
   12546 bytes, v3).
   bootsplash: status on console 3 changed to on
   bootsplash 3.1.6-2004/03/31: looking for picture...<6>...found (800x600,
   12546 bytes, v3).
   bootsplash: status on console 4 changed to on
   bootsplash 3.1.6-2004/03/31: looking for picture...<6>...found (800x600,
   12546 bytes, v3).
   bootsplash: status on console 5 changed to on
   atkbd.c: Unknown key pressed (translated set 2, code 0xd9 on
   isa0060/serio0).
   atkbd.c: Use 'setkeycodes e059 <keycode>' to make it known.
   atkbd.c: Unknown key pressed (translated set 2, code 0xd9 on
   isa0060/serio0).
   atkbd.c: Use 'setkeycodes e059 <keycode>' to make it known.
   ACPI: PCI Interrupt 0000:01:00.0[A] -> GSI 16 (level, low) -> IRQ 18
   NVRM: loading NVIDIA Linux x86 Kernel Module  1.0-9629  Wed Nov  1 19:30:07
   PST 2006
-> Installing both new and classic TLS OpenGL libraries.
-> Parsing log file:
-> done.
-> Validating previous installation:
-> done.
-> Uninstalling NVIDIA Accelerated Graphics Driver for Linux-x86 (1.0-9629):
-> done.
-> Uninstallation of existing driver: NVIDIA Accelerated Graphics Driver for
   Linux-x86 (1.0-9629) is complete.
-> Searching for conflicting X files:
-> done.
-> Searching for conflicting OpenGL files:
-> done.
-> Installing 'NVIDIA Accelerated Graphics Driver for Linux-x86' (1.0-9629):
   executing: '/sbin/ldconfig'...
   executing: '/sbin/depmod -aq'...
-> done.
-> Driver file installation is complete.
-> Running post-install sanity check:
-> done.
-> Post-install sanity check passed.
-> Shared memory test passed.
-> Running runtime sanity check:
-> done.
-> Runtime sanity check passed.
-> Would you like to run the nvidia-xconfig utility to automatically update you
   r X configuration file so that the NVIDIA X driver will be used when you res
   tart X?  Any pre-existing X configuration file will be backed up. (Answer: Y
   es)
-> Your X configuration file has been successfully updated.  Installation of
   the NVIDIA Accelerated Graphics Driver for Linux-x86 (version: 1.0-9629) is
   now complete.